@@ -1,8 +1,8 @@
 /* interface to the Ng/Peyton sparse Cholesky routines
  *
- * PCx beta-2.0   10/31/96. 
+ * PCx 1.1 11.97
  *
- * Authors: Joe Czyzyk, Sanjay Mehrotra, Steve Wright.
+ * Authors: Joe Czyzyk, Sanjay Mehrotra, Michael Wagner, Steve Wright.
  * 
  * (C) 1996 University of Chicago. See COPYRIGHT in main directory.
  */
@@ -18,8 +18,6 @@
 /* This is an implementation of solver.h for the Ng-Peyton Solver*/
 /*****************************************************************/
 
-#ifndef rs6000
-#ifndef hpux
 #define ordmmd    ordmmd_
 #define sfinit    sfinit_
 #define bfinit    bfinit_
@@ -30,8 +28,6 @@
 #define symfct    symfct_
 #define inpnv     inpnv_
 #define ordnat    ordnat_
-#endif
-#endif
 
 /*****************************************************************/
 /* Allocation and deallocation routines for the FactorType data  */
