@@ -1,8 +1,8 @@
 /* PCx() 
  *
- * PCx beta-2.0   10/31/96. 
+ * PCx 1.1 11/97
  *
- * Authors: Joe Czyzyk, Sanjay Mehrotra, Steve Wright.
+ * Authors: Joe Czyzyk, Sanjay Mehrotra, Michael Wagner, Steve Wright.
  * 
  * (C) 1996 University of Chicago. See COPYRIGHT in main directory.
  */
@@ -339,8 +339,7 @@ PCx(LP, Solution, Inputs)
       /* Save info about the current iterate, for possible later review */
 	 
 	 StoreHistory(Solution, Iteration, primal_objective, dual_objective,
-		      PriInf, DualInf, mu, NumCorrections, phi, 
-		      rhs2norm, cost2norm, NumCols, NumBounds);
+		      PriInf, DualInf, mu, NumCorrections, phi);
 	 
     /*******************************************************************/
     /* TERMINATION TESTS                                               */
