@@ -1,8 +1,8 @@
 /* LPtype <--> MPStype
  *
- * PCx beta-2.0   10/31/96. 
+ * PCx 1.1 11/97
  *
- * Authors: Joe Czyzyk, Sanjay Mehrotra, Steve Wright.
+ * Authors: Joe Czyzyk, Sanjay Mehrotra, Michael Wagner, Steve Wright.
  * 
  * (C) 1996 University of Chicago. See COPYRIGHT in main directory.
  */
@@ -194,6 +194,12 @@ LPtype  *Convert_MPS_LP(MPS, pChanges)
 	      LP->BoundIndex[LP->NumberBounds] = i;
 	      LP->NumberBounds++;
 	   } 
+
+/* changed 2/8/01 to handle the case in which the LP->UpBound[i] contains 
+   a nonzero, which is meant to be an upper bound on x[i], i.e.
+   -inf <= x[i] <= MPS->UpBound[i].
+   Need to convert this to a NORMAL variable by flipping and shifting */
+
 	else if (MPS->BoundType[i] == MINFTY) 
 	   {	/* flip the sign */
 	      Changes->SignChanges[i] = 1;
@@ -203,6 +209,18 @@ LPtype  *Convert_MPS_LP(MPS, pChanges)
 		    LP->A.Value[j] = -LP->A.Value[j];
 		 }
 	      LP->c[i] = -LP->c[i];
+                /* shift the sucker too, 
+                   its lower bound is -MPS->UpBound[i] */ 
+              if (LP->UpBound[i] != 0.0) {
+                Changes->VarShifts[i] = -MPS->UpBound[i]; 
+                LP->cshift -= LP->c[i] * MPS->UpBound[i]; 
+                for (j = LP->A.pBeginRow[i] - 1;
+                     j <= LP->A.pEndRow[i] - 1; j++)
+                   {
+                    inxrow = LP->A.Row[j] - 1;
+                    LP->b[inxrow] += LP->A.Value[j] * MPS->UpBound[i];
+                   }   
+              }
 	      LP->VarType[i] = NORMAL;
 	   }
      }
