@@ -1,10 +1,12 @@
 /* readmps
  *
- * PCx beta-2.0   10/31/96. 
+ * PCx 1.1 11/97
  *
- * Author: Joe Czyzyk
+ * Author: Joe Czyzyk, Steve Wright
  * 
  * (C) 1996 University of Chicago. See COPYRIGHT in main directory.
+ *
+ * last revised 2/27/2001
  */
 
 #include <stdio.h>
@@ -18,6 +20,7 @@
 #define PARSE_DEBUG  0
 #define HEADERLINE   1
 #define DATALINE     2
+#define READERROR    3
 
 #define ROW_INCREMENT  5
 #define COL_INCREMENT  5
@@ -84,16 +87,17 @@ int ReadMPSFile(corefile, MPS, Inputs)
 
   int             col, row, oldrow, entry;
   char            line[200], name1[15], name2[15], name3[15], code[5],
-                  OldColumnName[15];
+    OldColumnName[15];
+  int             return_getline;
   double          val1, val2;
   int             ColNumber, EntNumber, RowNumber;
   int             MPSQuickCheckBoundInfeasibility(),
-                  AddMPSRow(), AddMPSColumn(), AddMPSCoefficient(), 
-                  AddMPSRHS(), AddMPSBound(), AddMPSRange();
+    AddMPSRow(), AddMPSColumn(), AddMPSCoefficient(), 
+    AddMPSRHS(), AddMPSBound(), AddMPSRange();
 
   /* read header line */
 
-  if (GetLine(line, corefile, 200) == HEADERLINE) {
+  if ((return_getline = GetLine(line, corefile, 200)) == HEADERLINE) {
     ParseHeaderLine(line, name1, name2);
     if (strncmp(name1, "NAME", 4) != 0) {
       printf("Error reading MPS file.\n");
@@ -102,7 +106,7 @@ int ReadMPSFile(corefile, MPS, Inputs)
     }
     AddMPSProblemName(MPS, name2);
   } else {
-    printf("Missing NAME line in MPS file.\n");
+    printf("Read error or possibly missing NAME line in MPS file.\n");
     return BAD_INPUT;
   }
 
@@ -110,17 +114,20 @@ int ReadMPSFile(corefile, MPS, Inputs)
 
   /* read ROWS line */
 
-  if (GetLine(line, corefile, 200) == HEADERLINE) {
+  if ((return_getline = GetLine(line, corefile, 200)) == HEADERLINE) {
     ParseHeaderLine(line, name1, name2);
     if (strncmp(name1, "ROWS", 4) != 0) {
       printf("Missing ROWS line in MPS file.\n");
       return BAD_INPUT;
     } else if (DEBUG > 0)
       printf("Found ROWS line in MPS file.\n");
+  } else {
+    printf("Read error or possibly missing NAME line in MPS file.\n");
+    return BAD_INPUT;
   }
   /*****************************************************************/
 
-  while (GetLine(line, corefile, 200) == DATALINE) {
+  while ((return_getline = GetLine(line, corefile, 200)) == DATALINE) {
     ParseDataLine(line, code, name1, name2, &val1, name3, &val2);
 
     RowNumber = AddMPSRow(MPS, name1, code);
@@ -130,6 +137,17 @@ int ReadMPSFile(corefile, MPS, Inputs)
     }
   }				/* end while */
 
+  if(return_getline == READERROR) {
+    printf("Read error in MPS file.\n");
+    return BAD_INPUT;
+  }
+
+  /* Have we read an objective row by this point? If not, error! */
+  if(NoObjectiveRowName(MPS)) {
+    printf("No objective row found in ROWS section - error!\n");
+    return BAD_INPUT;
+  }
+
   /*****************************************************************/
 
   /* Process COLUMNS section */
@@ -144,7 +162,7 @@ int ReadMPSFile(corefile, MPS, Inputs)
 
   strcpy(OldColumnName, "");
 
-  while (GetLine(line, corefile, 200) == DATALINE) {
+  while ((return_getline = GetLine(line, corefile, 200)) == DATALINE) {
 
     ParseDataLine(line, code, name1, name2, &val1, name3, &val2);
 
@@ -159,8 +177,8 @@ int ReadMPSFile(corefile, MPS, Inputs)
     }
     EntNumber = AddMPSCoefficient(MPS, name1, name2, val1, Inputs);
     if(EntNumber == BAD_INPUT) {
-       printf("Bad Coefficient in MPS file\n");
-       return BAD_INPUT; 
+      printf("Bad Coefficient in MPS file\n");
+      return BAD_INPUT; 
     }
 
     if (val2 != 0.0) {
@@ -172,6 +190,11 @@ int ReadMPSFile(corefile, MPS, Inputs)
     }
   }				/* end while */
 
+  if(return_getline == READERROR) {
+    printf("Read error in MPS file.\n");
+    return BAD_INPUT;
+  }
+
 #if DEBUG > 1
   printf("Found %d columns in the constraint matrix.\n", ColNumber + 1);
   printf("Found %d entries in the constraint matrix.\n", EntNumber + 1);
@@ -187,8 +210,8 @@ int ReadMPSFile(corefile, MPS, Inputs)
     printf("Missing RHS statement in MPS file.\n");
     return BAD_INPUT;
   }
-  while (GetLine(line, corefile, 200) == DATALINE) {
-
+  while ((return_getline = GetLine(line, corefile, 200)) == DATALINE) {
+    
     ParseDataLine(line, code, name1, name2, &val1, name3, &val2);
 
     if (NoRHSName(MPS))
@@ -209,6 +232,11 @@ int ReadMPSFile(corefile, MPS, Inputs)
     }
   }				/* end while GetLine == DATALINE */
 
+  if(return_getline == READERROR) {
+    printf("Read error in MPS file.\n");
+    return BAD_INPUT;
+  }
+
   /*****************************************************************/
 
   ParseHeaderLine(line, name1, name2);
@@ -217,7 +245,7 @@ int ReadMPSFile(corefile, MPS, Inputs)
 #if (DEBUG > 0)
     printf("Found RANGES: %s\n", name1);
 #endif
-    while (GetLine(line, corefile, 200) == DATALINE) {
+    while ((return_getline = GetLine(line, corefile, 200)) == DATALINE) {
 
       ParseDataLine(line, code, name1, name2, &val1, name3, &val2);
 
@@ -226,7 +254,7 @@ int ReadMPSFile(corefile, MPS, Inputs)
 
       if (strcmp(MPS->RangeName, name1) == 0) {
 	/* only consider ranges with matching range name */
-
+	
 	if(AddMPSRange(MPS, name2, val1) == BAD_INPUT) {
           printf("Bad Range in MPS file\n");
           return BAD_INPUT; 
@@ -238,6 +266,12 @@ int ReadMPSFile(corefile, MPS, Inputs)
 	  }
       }
     }
+
+    if(return_getline == READERROR) {
+      printf("Read error in MPS file.\n");
+      return BAD_INPUT;
+    }
+    
   }
   /*****************************************************************/
 
@@ -248,8 +282,8 @@ int ReadMPSFile(corefile, MPS, Inputs)
     printf("Found BOUNDS: %s\n", name1);
 #endif
 
-    while (GetLine(line, corefile, 200) == DATALINE) {
-
+    while ((return_getline = GetLine(line, corefile, 200)) == DATALINE) {
+      
       ParseDataLine(line, code, name1, name2, &val1, name3, &val2);
 
       if (NoBoundName(MPS))
@@ -270,6 +304,12 @@ int ReadMPSFile(corefile, MPS, Inputs)
       } else
 	printf("Ignoring bounds with name '%s'.\n", name1);
     }
+
+    if(return_getline == READERROR) {
+      printf("Read error in MPS file.\n");
+      return BAD_INPUT;
+    }
+
   }
   /*****************************************************************/
 
@@ -1080,17 +1120,21 @@ GetLine(line, file, length)
   FILE           *file;
   int             length;
 {
+  char *return_line;
   int             i;
 
   do {
 
     for (i = 0; i < length; i++)
       line[i] = ' ';
-    fgets(line, length, file);	/* get line from file */
+    return_line = fgets(line, length, file);	/* get line from file */
 
-  } while (line[0] == '*');	/* discard comment lines */
+  } while (return_line != NULL && line[0] == '*'); /* discard comment lines */
 
-  return ((line[0] == ' ') ? DATALINE : HEADERLINE);
+  if(return_line == NULL) return READERROR;
+
+  if(line[0] == ' ') return DATALINE;
+  else return HEADERLINE;
 }
 
 /******************************************************************/
